Crate evenframe

Crate evenframe 

Re-exports

pub use linkme;

Modules

config
error
prelude
registry
schemasync
traits
types
validator
wrappers

Enums

EvenframeError

Type Aliases

Result

Derive Macros

Evenframe
For structs it generates both:
EvenframeUnion
Derive macro for unions of persistable structs Each variant must contain exactly one persistable struct type
Schemasync
Derive macro for types that only participate in database schema synchronization.
Typesync
Derive macro for types that only participate in TypeScript type generation.